Summary: GNU Plotting Utilities
Name: plotutils
Version: 2.2
Release: 1
Group: Applications/Graphics
Copyright: GPL
Url: http://www.gnu.org/software/plotutils/plotutils.html
Packager: Hao Li <hli@wag.caltech.edu>
Source: ftp://ftp.gnu.org/gnu/plotutils/plotutils-%{version}.tar.gz
BuildRoot: /var/tmp/%{name}-root

%description 
The GNU plotting utilities include: (1) Sample command-line applications
`graph', `plot', `tek2plot', and `plotfont', which are built on top of the
GNU libplot DLL.  `graph' is a powerful utility for XY plotting, `plot'
translates GNU metafiles to other formats, `tek2plot' translates legacy
Tektronix data, and `plotfont' plots character maps.  (2) GNU libplot, the
underlying DLL for two-dimensional device-independent vector graphics and
vector graphics animation under the X Window System.  Output formats
include X11, Adobe Illustrator, Postscript (editable with the free `idraw'
drawing editor), Fig (editable with the free `xfig' drawing editor), PCL 5,
HP-GL and HP-GL/2, Tektronix, and GNU metafile format.  Many Postscript,
PCL, and Hershey fonts are supported.  (3) Command-line applications
`spline', `double', and `ode', which are useful in scientific plotting.
`spline' does spline interpolation of input data of arbitrary
dimensionality.  It uses cubic splines, splines under tension, or cubic
Bessel interpolation.  `ode' is an interactive program that can integrate a
user-specified system of ordinary differential equations.


%prep
%setup -q


%build
./configure --prefix=/usr
make CFLAGS="$RPM_OPT_FLAGS"
make -C info plotutils.{dvi,ps}
gzip -9f info/plotutils.ps


%install
rm -rf $RPM_BUILD_ROOT
make install-strip DESTDIR=$RPM_BUILD_ROOT
gzip -9f $RPM_BUILD_ROOT/usr/info/plotutils.info

# install additional fonts per suggestion in INSTALL.fonts
mkdir -p $RPM_BUILD_ROOT/usr/X11R6/lib/X11/fonts/{Type1,misc}

# 1. The 35 standard Postscript fonts
# Note: ghostscript-fonts already provides these 35 fonts but they are
# installed under /usr/share/ghostscript/fonts by default so are not available
# to X directly.
install -m644 -p fonts/pfb/*.pfb $RPM_BUILD_ROOT/usr/X11R6/lib/X11/fonts/Type1

# 2. The 4 standard Tektronix fonts
install -m644 -p fonts/pcf/*.pcf $RPM_BUILD_ROOT/usr/X11R6/lib/X11/fonts/misc
gzip -9f $RPM_BUILD_ROOT/usr/X11R6/lib/X11/fonts/misc/*.pcf

# 3. The 45 standard LaserJet fonts
# The installation and using of these fonts are quite complicated so this 
# part is omitted for the time being. Read INSTALL.fonts if you need them.

# Collect files for %doc
mkdir -p rpm_doc/fonts
cp -p fonts/{README,fonts*.append,u_fonts.c} rpm_doc/fonts


%post
/sbin/install-info /usr/info/plotutils.info.gz /usr/info/dir
/sbin/ldconfig
(
  # Append fonts.append to fonts.scale
  TMP_FILE=/tmp/fonts.scale
  FNT_FILE=/usr/X11R6/lib/X11/fonts/Type1/fonts.scale
  APP_FILE=/usr/doc/plotutils-%{version}/fonts/fonts.append
  tail +2 $FNT_FILE > $TMP_FILE
  cat $APP_FILE >> $TMP_FILE
  wc -l < $TMP_FILE | tr -d " " > $FNT_FILE
  cat $TMP_FILE >> $FNT_FILE
  rm -f $TMP_FILE
)
cd /usr/X11R6/lib/X11/fonts/Type1 && mkfontdir
cd /usr/X11R6/lib/X11/fonts/misc  && mkfontdir
xset fp rehash 2> /dev/null || :

%preun
if [ $1 = 0 ]; then
    /sbin/install-info --delete /usr/info/plotutils.info.gz /usr/info/dir
fi

%postun
/sbin/ldconfig
(
  # Restore fonts.scale to describe only the remaining fonts
  TMP_FILE=/tmp/fonts.scale
  FNT_FILE=/usr/X11R6/lib/X11/fonts/Type1/fonts.scale
  FONTS=$(cd /usr/X11R6/lib/X11/fonts/Type1; echo *.pf[ab] | sed 's, ,|,g')
  egrep "^($FONTS) " $FNT_FILE > $TMP_FILE
  wc -l < $TMP_FILE | tr -d " " > $FNT_FILE
  cat $TMP_FILE >> $FNT_FILE
  rm -f $TMP_FILE
)
cd /usr/X11R6/lib/X11/fonts/Type1 && mkfontdir
cd /usr/X11R6/lib/X11/fonts/misc  && mkfontdir
xset fp rehash 2> /dev/null || :


%files
%defattr(-,root,root)
%doc AUTHORS COMPAT COPYING ChangeLog INSTALL INSTALL.fonts INSTALL.pkg
%doc KNOWN_BUGS NEWS ONEWS PROBLEMS README THANKS TODO
%doc doc info/plotutils.dvi info/plotutils.ps.gz rpm_doc/*
/usr/bin/*
/usr/include/*
/usr/info/*
/usr/lib/*
/usr/man/man*/*
/usr/share/libplot
/usr/share/ode
/usr/share/tek2plot
# These go into XFree86's font directory
/usr/X11R6/lib/X11/fonts/*/*


%clean
rm -rf $RPM_BUILD_ROOT
